L10n class

Constructors

L10n()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

codeAnglais String
getter/setter pair
codeArabic String
getter/setter pair
codeCreole String
getter/setter pair
codeEspagnole String
getter/setter pair
codeFrancais String
getter/setter pair
langAnglais LanguageModel
final
langArabic LanguageModel
final
langCreole LanguageModel
final
langEspagnole LanguageModel
final
langFrancais LanguageModel
final
languages1 List<Locale>
final
languages_en_fr_es_ht List<LanguageModel>
getter/setter pair
languagesLocal List<Locale>
final
languagesStr List<String>
final
langueAnglais Locale
final
langueArabic Locale
final
langueCreole Locale
final
langueEspagnole Locale
final
langueFrancais Locale
final
storageKey String
final
storageKeyLanguage String
final

Static Methods

getFlag(String code) String
getLanguage(dynamic deviceLocale, dynamic supportedLocales) Locale
getLangueStr({required Langue langue}) → dynamic