EnvironmentVariable class

Constructors

EnvironmentVariable()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

appImage ImageModel
no setter
appLanguages List<LanguageModel>
no setter
appName String
no setter
appTranslator Map<String, Map<String, String>>
no setter
assetsPathLanguage String
no setter
assetsPathLanguageToMerge String
no setter
endPointApi EndPointApiModel
no setter
environmentType EnumEnvironmentType
no setter
firebaseOptions → dynamic
no setter
no setter
isBibleActive bool
no setter
isConnectionRequired bool
no setter
name String
no setter
templateLogin EnumTemplateLogin
no setter
urlApiServer String
no setter
urlWebServer String
no setter

Static Methods

flavorConfigVariables({required String variableName}) → dynamic