GoogleAdsModel class

Constructors

GoogleAdsModel({bool isShowBrainBanner = true, String? appIdAdMobAndroid, String? appOpenAdMobAndroid, String? bannerAdMobAndroid, String? interstitielAdMobAndroid, String? rewardedAdMobAndroid, String? rewardedInterstitielAdMobAndroid, String? natifAdvancedAdMobAndroid, String? appIdAdMobIOS, String? appOpenAdMobIOS, String? bannerAdMobIOS, String? interstitielAdMobIOS, String? rewardedAdMobIOS, String? rewardedInterstitielAdMobIOS, String? natifAdvancedAdMobIOS})
GoogleAdsModel.fromJson(Map<String, dynamic> map)
factory

Properties

appIdAdMobAndroid String?
getter/setter pair
appIdAdMobIOS String?
getter/setter pair
appOpenAdMobAndroid String?
getter/setter pair
appOpenAdMobIOS String?
getter/setter pair
bannerAdMobAndroid String?
getter/setter pair
bannerAdMobIOS String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
interstitielAdMobAndroid String?
getter/setter pair
interstitielAdMobIOS String?
getter/setter pair
isShowBrainBanner bool
getter/setter pair
natifAdvancedAdMobAndroid String?
getter/setter pair
natifAdvancedAdMobIOS String?
getter/setter pair
rewardedAdMobAndroid String?
getter/setter pair
rewardedAdMobIOS String?
getter/setter pair
rewardedInterstitielAdMobAndroid String?
getter/setter pair
rewardedInterstitielAdMobIOS String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited