ImageModel class

Constructors

ImageModel({required String logoCircleLight, String? logoCircleDark, String? logoSquareLight, String? logoSquareDark, String? bgImageLight, String? bgImageDark})
ImageModel.fromJson(Map<String, dynamic> map)
factory

Properties

bgImageDark String?
getter/setter pair
bgImageLight String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
logoCircleDark String?
getter/setter pair
logoCircleLight String
getter/setter pair
logoSquareDark String?
getter/setter pair
logoSquareLight String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited