ApplicationController class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • ApplicationController
Implemented types

Constructors

ApplicationController({required ApiClient apiClient, required SharedPreferences sharedPref, required SettingsRepository settingsRepository, required DeviceAppVersionRepository deviceAppVersionRepository})

Properties

apiClient ApiClient
getter/setter pair
checkIsFirstBackUpOnline bool
getter/setter pair
counter int
getter/setter pair
dataResult List?
getter/setter pair
deviceAppVersion DeviceAppVersionModel
getter/setter pair
deviceAppVersionRepository DeviceAppVersionRepository
getter/setter pair
duration Duration
getter/setter pair
flexibleUpdateAvailable bool
no setter
flexibleUpdateAvailable1 bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
iconListOrGrid IconData
no setter
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isAListViewMenuChant bool
getter/setter pair
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isList bool
no setter
isShowBottomNavigationBarMenu bool
no setter
labelFormatListOrGrid String
no setter
listeners int
no setterinherited
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
packageInfo → PackageInfo
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedTabHomePageIndex int
getter/setter pair
selectedTabHomePageIndexV2 int
getter/setter pair
selectedTabPageIndex int
getter/setter pair
settings SettingsModel
getter/setter pair
settingsRepository SettingsRepository
getter/setter pair
sharedPref → SharedPreferences
final
showCircularProgress bool
no setter
showSearch bool
getter/setter pair

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
checkFirstBackUpOnline() → dynamic
checkOrUpdateApp() Future
checkUpdateOnServer() Future
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
fetchLanguages() Future
fetchSettings() Future
getDbNameBible() → dynamic
getDbNameBible2() Future<String>
getDbNameBibleWithOutExtension() Future<String>
getFormatListOrGrid() → dynamic
getIsAListView() bool
getIsAListViewMenuChant() → dynamic
getIsDbBibleChange() Future<bool>
getIsDbBibleChange2() Future<bool>
getIsFirstDbBibleCopy() Future<bool>
getIsNewFirstDbBibleCopy() Future<bool>
getIsShowBottomNavigationBarMenu() → dynamic
initData() → dynamic
initPackageState() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
inherited
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
selectPage(int index) → void
selectTabHomePageIndex(int index) → void
selectTabHomePageIndexV2(int index) → void
setDbNameBible(String value) → dynamic
setDbNameBible2(String value) → dynamic
setFormatListOrGrid() → void
setIsAListView(bool value) → dynamic
setIsAListViewMenuChant() → dynamic
setIsDbBibleChange(bool value) → dynamic
setIsDbBibleChange2(bool value) → dynamic
setIsFirstDbBibleCopy(bool value) → dynamic
setIsNewFirstDbBibleCopy(bool value) → dynamic
setIsShowBottomNavigationBarMenu(bool value) → dynamic
showCircularProgressIndicator({bool show = true}) → dynamic
showDialogProgress({bool show = true}) → dynamic
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited