ThemeController class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • ThemeController
Implemented types

Constructors

ThemeController({required SharedPreferences sharedPreferences})

Properties

alignText String
no setter
allowsNotifications bool
no setter
brightness Brightness
no setter
colorTheme Color?
no setter
colorTheme1 Color
no setter
colorTheme2 MaterialColor
getter/setter pair
colorThemeData Color
no getter
fontSize double
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
imgBg String
no setter
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isBrightnessDark bool
no setter
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isShowCaseCViewDetailEnable bool
getter/setter pair
isShowCaseHome2Time bool
getter/setter pair
isShowCaseHomeEnable bool
getter/setter pair
isSplitEnable bool
no setter
labelTheme String
no setter
letterSpacing double
no setter
listeners int
no setterinherited
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
pdlClick int
no setter
quizClick int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharedPreferences → SharedPreferences
final
spaceBetweenVerses double
no setter
wordSpacing double
no setter

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
getAlignText() → dynamic
getAllowsNotifications() → dynamic
getFontSize() → dynamic
getIsBrightnessDark() → dynamic
getIsSplitEnable() → dynamic
getLetterSpacing() → dynamic
getPdlClick() → dynamic
getPrimaryColorSwatch() → dynamic
getQuizClick() → dynamic
getSpaceBetweenVerses() → dynamic
getWordSpacing() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
inherited
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
setAlignText(String value) → dynamic
setAllowsNotifications(bool value) → dynamic
setColorTheme(int value) → dynamic
setFontSize(double value) → dynamic
setIsSplitEnable(bool value) → dynamic
setLetterSpacing(double value) → dynamic
setPdlClick(int value) → dynamic
setQuizClick() → dynamic
setSpaceBetweenVerses(double value) → dynamic
setWordSpacing(double value) → dynamic
showColorThemeDialog() → dynamic
showModalBottomParametresSystems() → dynamic
toggleSplitEnable() → dynamic
toggleTheme() → void
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited