PagerProperty class

Constructors

PagerProperty()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

currentPage Property
final
data Property
final
firstPageUrl Property
final
from Property
final
lastPage Property
final
lastPageUrl Property
final
final
nextPageUrl Property
final
path Property
final
perPage Property
final
prevPageUrl Property
final
to Property
final
total Property
final