MySharedPref class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
getter/setter pair
Methods
-
getCurrentPosition(
) → Future< int> -
getDbNameBible(
) → Future< String> -
getDbNameBible2(
) → Future< String> -
getDbNameBibleWithOutExtension(
) → Future< String> -
getDifficultyQuiz(
) → dynamic -
getIdAutoIncrement(
{required String tableNameKey}) → Future< int> -
getIsAListView(
) → Future< bool> -
getIsAListViewPdl(
) → Future< bool> -
getIsDbBibleChange(
) → Future< bool> -
getIsDbBibleChange2(
) → Future< bool> -
getIsFirstDbBibleCopy(
) → Future< bool> -
getIsNewFirstDbBibleCopy(
) → Future< bool> -
getIsNewVersionBibleDownload(
{required String fileName}) → Future< bool> -
getIsOnlineModeActivate(
) → Future< bool> -
getIsReminderToReadPlan(
) → dynamic -
getIsShowBottomSheetQuiz(
) → dynamic -
getIsVersionBibleDownload(
{required String fileName}) → Future< bool> -
getNbrOfQuestionsQuiz(
) → dynamic -
getPaddingBottomSheet(
) → Future< double> -
getRecompenseAds(
) → Future< int> -
getRecompenseAdsQR(
) → Future< int> -
getReminderDownloadNewVersionBible(
) → Future< bool> -
getReminderDownloadVersionBible(
) → Future< bool> -
getTextSize(
) → Future< double> -
getTextSizeFullScreen(
) → Future< double> -
getTimeReminderReadPlan(
) → dynamic -
idAutoIncrement(
{required String tableNameKey}) → Future< int> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setCurrentPosition(
int value) → dynamic -
setDbNameBible(
String value) → dynamic -
setDbNameBible2(
String value) → dynamic -
setDifficultyQuiz(
String value) → dynamic -
setIdAutoIncrement(
int value, {required String tableNameKey}) → dynamic -
setIsAListView(
bool value) → Future< bool> -
setIsAListViewPdl(
bool value) → Future< bool> -
setIsDbBibleChange(
bool value) → dynamic -
setIsDbBibleChange2(
bool value) → dynamic -
setIsFirstDbBibleCopy(
bool value) → dynamic -
setIsNewFirstDbBibleCopy(
bool value) → dynamic -
setIsNewVersionBibleDownload(
bool value, {required String fileName}) → dynamic -
setIsOnlineModeActivate(
bool value) → Future< bool> -
setIsReminderToReadPlan(
bool value) → dynamic -
setIsShowBottomSheetQuiz(
bool value) → dynamic -
setIsVersionBibleDownload(
bool value, {required String fileName}) → dynamic -
setNbrOfQuestionsQuiz(
int value) → dynamic -
setPaddingBottomSheet(
double value) → dynamic -
setRecompenseAds(
int value) → dynamic -
setRecompenseAdsQR(
int value) → dynamic -
setReminderDownloadNewVersionBible(
bool value) → dynamic -
setReminderDownloadVersionBible(
bool value) → dynamic -
setTextSize(
double value) → dynamic -
setTextSizeFullScreen(
double value) → dynamic -
setTimeReminderReadPlan(
String value) → dynamic -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited