ErrorResponseModel class

Constructors

ErrorResponseModel({required Map<String, List<String>>? errors, required String type, required String title, required int status, required String traceId})
ErrorResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

errors Map<String, List<String>>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int
final
title String
final
traceId String
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

messages({ErrorResponseModel? errorResponse}) String