InfoModel class
Constructors
Properties
- apiVersion ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- jwtToken ↔ String
-
getter/setter pair
- permissions ↔ String
-
getter/setter pair
- roleCode ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
convertToJsonList(
List< InfoModel> data) → dynamic -
fromJsonList(
dynamic data) → List< InfoModel>