DeepLinksModel class

Constructors

DeepLinksModel({String? initialLink, String latestLink = 'Unknown', Uri? initialUri, String? latestUriPath, Uri? latestUri, List<MapEntry<String, List<String>>>? queryParams, Object? objArguments, List<Object>? booksListArg1, List<Object>? pdlBooksListArg2, List<Object>? booksListFromdbArg3})

Properties

booksListArg1 List<Object>?
getter/setter pair
booksListFromdbArg3 List<Object>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
getter/setter pair
initialUri Uri?
getter/setter pair
getter/setter pair
latestUri Uri?
getter/setter pair
latestUriPath String?
getter/setter pair
objArguments Object?
getter/setter pair
pdlBooksListArg2 List<Object>?
getter/setter pair
queryParams List<MapEntry<String, List<String>>>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

convertToJson() Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

toJsonList(List<DeepLinksModel> data) → dynamic