LanguageModel class

Constructors

LanguageModel({String imageUrl = '', String languageName = '', String countryCode = '', String languageCode = ''})

Properties

countryCode String
final
hashCode int
The hash code for this object.
no setterinherited
imageUrl String
final
languageCode String
final
languageName String
final
local Locale
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited