TabControlModel class

Constructors

TabControlModel({required List<Tab> tabsHeaderList, required List<Widget> widgetsContentTab, required int indexTabSelected, int nbrChapitreARattrapper = 0, int nbrJourARattrapper = 0})

Properties

hashCode int
The hash code for this object.
no setterinherited
indexTabSelected int
getter/setter pair
nbrChapitreARattrapper int
getter/setter pair
nbrJourARattrapper int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabsHeaderList List<Tab>
getter/setter pair
widgetsContentTab List<Widget>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited