LangueModel class
Constructors
- LangueModel({String name = '', String value = '', String flag = ''})
-
LangueModel.fromJson(Map<
String, dynamic> map) -
factory
Properties
- flag ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setter
- name ↔ String
-
getter/setter pair
- nameDefault → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJsonList(
dynamic data) → List< LangueModel>