MenuAlignmentModel class
Constructors
- MenuAlignmentModel({String? title, String? subTitle, IconData? icon, String? value, ActionsMenuAlignment? actionsMenu})
Properties
- actionsMenu ↔ ActionsMenuAlignment?
-
getter/setter pair
-
getIconAlignList
↔ List<
MenuAlignmentModel> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon ↔ IconData?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subTitle ↔ String?
-
getter/setter pair
- title ↔ String?
-
getter/setter pair
- value ↔ String?
-
getter/setter pair
Methods
-
getIconAlignment(
String alignment) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited