PaginationModel class

Constructors

PaginationModel({int? currentPage, String? firstPageUrl, int? from, int? lastPage, String? lastPageUrl, List<LinksModel>? links, String? nextPageUrl, String? path, String? perPage, String? prevPageUrl, int? to, int total = 0})
PaginationModel.fromJson(Map<String, dynamic> json, {required String classObject, required dynamic objData})
factory

Properties

currentPage int?
getter/setter pair
data List
getter/setter pair
firstPageUrl String?
getter/setter pair
from int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lastPage int?
getter/setter pair
lastPageUrl String?
getter/setter pair
getter/setter pair
nextPageUrl String?
getter/setter pair
path String?
getter/setter pair
perPage String?
getter/setter pair
prevPageUrl String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to int?
getter/setter pair
total int
getter/setter pair

Methods

fromJson(String str, {required dynamic classObject, required dynamic objData}) PaginationModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJsonHelperList({required dynamic json, required String classObject, required dynamic objData}) → dynamic