PaginationQuestionModel class

Constructors

PaginationQuestionModel({int? currentPage, int? pageNumber, int? nbrPage, int? nbrRecord, List<Object>? questionsList})
PaginationQuestionModel.fromJson(Map<String, dynamic> map)
factory

Properties

currentPage int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
nbrPage int?
getter/setter pair
nbrRecord int?
getter/setter pair
pageNumber int?
getter/setter pair
questionsList List<Object>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited