SettingsModel class

Constructors

SettingsModel({required String id, String fcmKey = '', bool autoApprove = false, String privacyPolicy = '', String termsAndConditions = ''})
SettingsModel.fromJson(Map<String, dynamic> json)
factory

Properties

autoApprove bool
getter/setter pair
fcmKey String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
privacyPolicy String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
termsAndConditions String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited