CheckPlatform class
Constructors
- CheckPlatform()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAndroid → bool
-
no setter
- isApple → bool
-
no setter
- isDesktop → bool
-
no setter
- isDesktopSansMacOS → bool
-
no setter
- isIOS → bool
-
no setter
- isLinux → bool
-
no setter
- isMacOS → bool
-
no setter
- isMobile → bool
-
no setter
- isMobileOrWeb → bool
-
no setter
- isWeb → bool
-
no setter
- isWebOrIsDesktop → bool
-
no setter
- isWebOrIsDesktopSansMacOS → bool
-
no setter
- isWindows → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPackageData(
) → Future< PackageInfo> -
initPackageState(
) → Future< BuildConfig> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited