DialogView class

Constructors

DialogView()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

confirmationSuppression({required Widget widgetContentMsg, dynamic onPressedOui()?, dynamic onPressedNo()?, String? dialogTitle}) Future<void>
showAlertDialog({required String msg, String eors = "E"}) Future<void>
showAlertToast({required String msg, Alignment? alignment, String eors = "i"}) → dynamic
showToast(String msg, {Alignment? alignment, String eors = "i"}) → dynamic