GlobalPreference class

Constructors

GlobalPreference()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAlignText() Future<String>
getCurrentPosition() Future<int>
getIsDarkModeSysteme() Future<bool>
getIsFirstLoad() Future<bool>
getIsLanguageSysteme() Future<bool>
getTextSize() Future<double>
getTextSizeFullScreen() Future<double>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAlignText(String value) → dynamic
setCurrentPosition(int value) → dynamic
setIsDarkModeSysteme(bool value) → dynamic
setIsFirstLoad(bool value) → dynamic
setIsLanguageSysteme(bool value) → dynamic
setTextSize(double value) → dynamic
setTextSizeFullScreen(double value) → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

sharedPref ↔ SharedPreferences?
getter/setter pair