KeyValueModel class

Constructors

KeyValueModel({String key = '', String value = '', String desc = '', String flag = '', int valueInt = -1, bool selected = false})
KeyValueModel.fromJsonCountResultatByFormCode(Map<String, dynamic> map)
factory

Properties

desc String
getter/setter pair
flag String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
no setter
key String
getter/setter pair
name String
no setter
nameDefault String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
getter/setter pair
value String
getter/setter pair
valueInt int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited