MyIconChoice class

Constructors

MyIconChoice({int? id, required IconData icon, required String title, required String imagePath})

Properties

hashCode int
The hash code for this object.
no setterinherited
icon IconData
final
id int?
getter/setter pair
imagePath String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited