MyLauncher class

Constructors

MyLauncher()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

launchStatus(BuildContext context, AsyncSnapshot<void> snapshot) → dynamic
launchUniversalLinkIos(String url) Future<void>
makePhoneCall(String phoneNumber) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

launchInAppBrowser(String url) Future<void>
launchInBrowser(String url) Future<void>
launchInWebViewOrVC(String url) Future<void>