ImageIconResources class

Constructors

ImageIconResources()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

favorite_sharp IconData
getter/setter pair
iconsShare IconData
getter/setter pair

Static Methods

checkCircleActiveModeSombreOrNot() IconData
share() IconData
youtubeIconWidget({double horizontal = 5, double vertical = 10}) → dynamic