Sanitizer class

Constructors

Sanitizer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

DECODE_UTF_8(String Sentences) String
getChapitre(String value, {int? returnType}) → dynamic
GetTextFromHtml(String htmlText) String
getVerset({double? valueDouble, String? valueString}) → dynamic
getVerset4Note(String value, {int? position, int? returnType}) → dynamic
replaceHtmlBreakAndStrongToSlashN(String Sentences) String
replaceHtmlBreakToSlashN(String Sentences) String
ReplaceSlashNToHtmlBreak(String Sentences) String
replaceSpecialChar(String value) → dynamic
UNCODE_UTF_8(String Sentences) String
UNCODE_UTF_8_Old(String Sentences) String
UnCodeSpecialChar(String Sentences) String
utf8Word(String sentences) String