getClip method
Returns a description of the clip given that the render object being clipped is of the given size.
Implementation
@override
Path getClip(Size size) {
final path = Path();
path.lineTo(0.0, size.height - 50);
var firstEndPoint = Offset(size.width * 0.6, size.height - 29 - 50);
var firstControlPoint = Offset(size.width * .25, size.height - 60 - 50);
path.quadraticBezierTo(firstControlPoint.dx, firstControlPoint.dy,
firstEndPoint.dx, firstEndPoint.dy);
var secondEndPoint = Offset(size.width, size.height - 60);
var secondControlPoint = Offset(size.width * 0.84, size.height - 50);
path.quadraticBezierTo(secondControlPoint.dx, secondControlPoint.dy,
secondEndPoint.dx, secondEndPoint.dy);
path.lineTo(size.width, size.height);
path.lineTo(size.width, 0);
path.close();
return path;
}