ShowCaseButton class

Inheritance

Constructors

ShowCaseButton({Key? key, required GlobalKey<State<StatefulWidget>> globalKey, List<GlobalKey<State<StatefulWidget>>>? globalKeys, required Widget child, required String description, String? title, bool showButtonSkip = false, double height = 50, double width = 120, EdgeInsets targetPadding = EdgeInsets.zero, Color tooltipBackgroundColor = Colors.white, Color textColor = Colors.black, ShapeBorder targetShapeBorder = const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(8))), TooltipActionConfig? tooltipActionConfig = const TooltipActionConfig(alignment: MainAxisAlignment.end, position: TooltipActionPosition.outside, gapBetweenContentAndAction: 10)})
const

Properties

child Widget
final
description String
final
globalKey GlobalKey<State<StatefulWidget>>
final
globalKeys List<GlobalKey<State<StatefulWidget>>>?
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showButtonSkip bool
final
targetPadding EdgeInsets
Padding around target widget
final
targetShapeBorder ShapeBorder
ShapeBorder of the highlighted box when target widget will be showcased.
final
textColor Color
Defines text color of default tooltip when titleTextStyle and descTextStyle is not provided.
final
title String?
final
tooltipActionConfig → TooltipActionConfig?
Provide a configuration for tooltip action widget like alignment, position, gap, etc...
final
tooltipBackgroundColor Color
Defines background color for tooltip widget.
final
width double
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buttonOption({required ThemeController themeCtr, required BuildContext context}) → dynamic
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showcaseWithWidget({required ThemeController themeCtr, required BuildContext context}) → dynamic
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited