onPress property

VoidCallback? onPress
final

The gradient decoration for this SpeedDial The shape of the gradient decoration for this SpeedDial Whether speedDial initialize with open state or not, defaults to false. Whether to close the dial on pop if it's open. Executed when the dial is opened. Executed when the dial is closed. Executed when the dial is pressed. If given, the dial only opens on long press!

Implementation

//final Gradient? gradient;

/// The shape of the gradient decoration for this `SpeedDial`
//final BoxShape gradientBoxShape;

/// Whether speedDial initialize with open state or not, defaults to false.
//final bool isOpenOnStart;

/// Whether to close the dial on pop if it's open.
//final bool closeDialOnPop;
/// Executed when the dial is opened.
//final VoidCallback? onOpen;

/// Executed when the dial is closed.
//final VoidCallback? onClose;

/// Executed when the dial is pressed. If given, the dial only opens on long press!
final VoidCallback? onPress;