ApiClient class
Inheritance
Object
GetLifeCycle
DisposableInterface
GetxService
ApiClient
Constructors
ApiClient ({required String appBaseUrl , required SharedPreferences sharedPreferences , required BaseDeviceInfo deiceInfo , required String uniqueId })
Methods
$configureLifeCycle ()
→ void
inherited
deleteData ({required String apiUrl , String ? fName , dynamic data })
→ dynamic
deleteData2 (String uri , { })
→ Future <Response >
getApiToken ()
→ Future <String >
getData (String apiUrl , {String ? fName , dynamic data })
→ dynamic
getData3 (String uri , {Map <String , dynamic > ? query , })
→ Future <Response >
getData4 (String uri , {Map <String , dynamic > ? query , })
→ Future <Response >
getDeviceId ()
→ String
handleResponse (Response response , String uri )
→ Response
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onClose ()
→ void
Called before onDelete method. onClose might be used to
dispose resources used by the controller. Like closing events,
or streams before the controller is destroyed.
Or dispose objects that can potentially create some memory leaks,
like TextEditingControllers, AnimationControllers.
Might be useful as well to persist some data on disk.
inherited
onInit ()
→ void
Called immediately after the widget is allocated in memory.
You might use this to initialize something for the controller.
inherited
onReady ()
→ void
Called 1 frame after onInit(). It is the perfect place to enter
navigation events, like snackbar, dialogs, or a new route, or
async request.
inherited
patchData ({required String apiUrl , String ? fName , dynamic data })
→ dynamic
postData ({required String apiUrl , String ? fName , dynamic data })
→ dynamic
postData2 (String uri , dynamic body , { })
→ Future <Response >
postMultipartData (String uri , Map <String , String > body , List <MultipartBody > multipartBody , { })
→ Future <Response >
putData ({required String apiUrl , String ? fName , dynamic data })
→ dynamic
putData2 (String uri , dynamic body , {Map <String , dynamic > ? query , String contentType = '' , dynamic decoder (dynamic )?, dynamic uploadProgress (double )? })
→ Future <Response >
putMultipartData (String uri , Map <String , String > body , List <MultipartBody > multipartBody , { })
→ Future <Response >
saveUserToken (String token )
→ Future <bool >
setApiToken (String apiToken )
→ dynamic
setDeviceId (String deviceId )
→ dynamic
setPackageInfo (PackageInfo package )
→ dynamic
toString ()
→ String
A string representation of this object.
inherited