ApiConstantDev class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- apiUrlRefreshDeviceToken ↔ String
-
getter/setter pair
- apiUrlSetDeviceToken ↔ String
-
getter/setter pair
- apiV1 ↔ String
-
getter/setter pair
- apiV2 ↔ String
-
getter/setter pair
- urlApiAutoAuthenticate ↔ String
-
getter/setter pair
- urlApiDeleteAllDataUser ↔ String
-
getter/setter pair
- urlApiDeviceToken ↔ String
-
getter/setter pair
- urlApiLoginRegisterProvider ↔ String
-
getter/setter pair
- urlApiRegister ↔ String
-
getter/setter pair
- urlApiServer → String
-
no setter
- urlApiSettings ↔ String
-
getter/setter pair
- urlApiUpdatePhotoProfile ↔ String
-
getter/setter pair
- urlApiUpdateProfile ↔ String
-
getter/setter pair
- urlApiUser ↔ String
-
getter/setter pair
- urlServerImageNotification → String
-
no setter
- urlWebServer → String
-
no setter
Static Methods
-
urlApiDeviceAppVersion(
{dynamic packageName}) → String -
urlApiGetProfilPublicUserData(
{dynamic userName}) → String -
urlApiGetProfilUserData(
{dynamic userName}) → String -
urlApiUserByUserName(
{dynamic userName}) → String