RouteNameTools class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- editProfilePage → const String
- editProfileScreen → const String
- idVar → const String
- indexTabVar → const String
- informationScreen → const String
- nameVar → const String
- pageVar → const String
- profilePage → const String
- recoveryPasswordPage → const String
- redirectVar → const String
- registerPage → const String
- routeLogin → const String
- routeLoginWeb → const String
- userVar → const String
- verifyEmailPage → const String