Constant class

Constructors

Constant({int id = 0, String title = '', String titleWithOutBreak = '', String imagePath = '', dynamic colorData})

Properties

colorData ↔ dynamic
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pair
imagePath String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
getter/setter pair
titleWithOutBreak String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

ALL String
getter/setter pair
appName String
getter/setter pair
appStoreIdentifierCCG String
no setter
appStoreIdentifierLSB String
getter/setter pair
appStoreIdIdentifierCCG String
no setter
ASK_BC_FAVORIS String
getter/setter pair
assets_chant_json String
getter/setter pair
audioExtensionsAllowed List<String>?
getter/setter pair
codeAT String
getter/setter pair
codeCanonique String
getter/setter pair
codeChronologique String
getter/setter pair
codeHistorique String
getter/setter pair
codeLectureATEn3Mois String
getter/setter pair
codeLectureATEn6Mois String
getter/setter pair
codeLectureCanoniqueEn1An String
getter/setter pair
codeLectureCanoniqueEn2Ans String
getter/setter pair
codeLectureCanoniqueEn6Mois String
getter/setter pair
codeLectureCanoniqueEn90Jours String
getter/setter pair
codeLectureChronologiqueEn1An String
getter/setter pair
codeLectureChronologiqueEn2Ans String
getter/setter pair
codeLectureChronologiqueEn6Mois String
getter/setter pair
codeLectureChronologiqueEn90Jours String
getter/setter pair
codeLectureHistoriqueEn1An String
getter/setter pair
codeLectureHistoriqueEn2Ans String
getter/setter pair
codeLectureHistoriqueEn6Mois String
getter/setter pair
codeLectureHistoriqueEn90Jours String
getter/setter pair
codeLectureNTEn3Mois String
getter/setter pair
codeLectureNTEn6Mois String
getter/setter pair
codeNT String
getter/setter pair
copyRightAppName String
getter/setter pair
copyRightDeveloppeur String
getter/setter pair
COUNTRY_CODE String
getter/setter pair
data_chant_04_choeur_dadoration String
getter/setter pair
data_chant_05_chorale_centrale_eebv String
getter/setter pair
data_chant_06_chorale_sichem_eebv String
getter/setter pair
data_chant_09_groupe_praise_him_eebv String
getter/setter pair
data_chant_12_desperance String
getter/setter pair
data_chant_13_melodies_joyeuses String
getter/setter pair
data_chant_14_haiti_chante_avec_radio_lumiere String
getter/setter pair
data_chant_15_la_voix_du_reveil String
getter/setter pair
data_chant_16_reveillons_nous String
getter/setter pair
data_chant_17_echos_des_elus String
getter/setter pair
data_chant_18_lombre_du_reveil String
getter/setter pair
data_chant_19_gloire_a_lagneau String
getter/setter pair
data_chant_20_reveillons_nous_chretiens String
getter/setter pair
data_chant_21_les_cantiques_de_beraca String
getter/setter pair
data_chant_22_des_cantiques_speciaux String
getter/setter pair
data_groupe_chantant_json String
getter/setter pair
DATA_JSON_SECTION_CHANT String
getter/setter pair
extensionsPdf List<String>
getter/setter pair
format_EEEEddMMMyyyy_space String
getter/setter pair
format_yyyyMMdd ↔ DateFormat
getter/setter pair
formatToSave_dd_MM_yyyy ↔ DateFormat
getter/setter pair
imageExtensionsAllowed List<String>?
getter/setter pair
initialVideoId String
getter/setter pair
initialVideoLinkCCG String
getter/setter pair
LANGUAGE_CODE String
getter/setter pair
listCodeLectureAT List<String>
getter/setter pair
listCodeLectureCanonique List<String>
getter/setter pair
listCodeLectureChronologique List<String>
getter/setter pair
listCodeLectureHistorique List<String>
getter/setter pair
listCodeLectureNT List<String>
getter/setter pair
listCodePlanDeLectureLocal List<String>
getter/setter pair
monOrdreDeLecture int
getter/setter pair
ordreCanonique int
getter/setter pair
packageChurchManagerMobile String
getter/setter pair
solfegeExtensionsAllowed List<String>?
getter/setter pair
SPLIT_DATA_URL_VIDEO String
final
textAlign String
getter/setter pair
textSize String
getter/setter pair
uniquementPourUnLivre int
getter/setter pair
urlAppleStoreCCG String
getter/setter pair
urlAppleStoreLSB String
getter/setter pair
urlChantDefault String
getter/setter pair
urlGoogleStoreCCG String
no setter
urlGoogleStoreLSB String
getter/setter pair
urlMyAccountGooglePersonalInfo String
getter/setter pair
urlPrivacyPolicyCCG String
getter/setter pair
urlPrivacyPolicyLaSainteBible String
getter/setter pair
urlWebSiteBrainDev String
getter/setter pair
urlWebSiteCCG String
getter/setter pair
urlWebSiteChantCCG String
getter/setter pair
urlWebSiteLaBible String
getter/setter pair
urlWebSiteLSB String
getter/setter pair
urlWebSiteRezo509 String
getter/setter pair
USERS String
getter/setter pair

Static Methods

isCodeLectureListSystem({required List<String> codeList, required String? codeLecture}) → dynamic
urlAppCCGMobileOnly() String
urlAppleOrGoogleStoreCCG() String
urlAppleOrGoogleStoreLSB() String
urlAppMobileCCG({bool is4Share = true}) String
urlAppMobileLSB({bool is4Share = true}) String

Constants

alignCenter → const String
alignLeft → const String
alignRight → const String
API_TOKEN → const String
API_TOKEN_EXPIRATION_DATE → const String
assetsBiblePath → const String
assetsDbsPath → const String
assetsPath → const String
asv14DbName → const String
bdsDbName → const String
bookCE → const String
bookCEEBV → const String
bpvDbName → const String
btxDbName → const String
channel_notification_song_share → const String
chant_Chorale_et_Groupe_APP_Abonne_05 → const int
Chant_Internaute_23 → const int
choixMultipleCheckBox → const int
choixUniqueCombo → const int
choixUniqueRadio → const int
closeAfter → const String
codeCategorieUserPLAN → const String
codeUserSystem → const String
dataBaseName → const String
dbyDbName → const String
defaultDbNameBible → const String
DEVICE_ID → const String
dmbDbName → const String
doubleNew → const int
frc97DbName → const String
gotoNext → const int
gotoNextStr → const String
gotoPreviews → const int
gotoPreviewsStr → const String
groupe0 → const String
groupe1 → const String
groupe2 → const String
groupeIdAT → const int
groupeIdNA → const int
groupeIdNT → const int
groupeIds → const List<int>
GS_DEV → const String
GUID_EMPTY → const String
hcbDbName → const String
hcvDbName → const String
icbDbName → const String
idFirstBookAT → const int
idFirstBookNT → const int
idLastBookAT → const int
idLastBookNT → const int
intNew → const int
jlxxDbName → const String
kjv1611DbName → const String
kjvDbName → const String
logolaSainteBible → const String
lsg2DbName → const String
lsgDbName → const String
maxOfBook66 → const int
nbrChapitreAT → const int
nbrChapitreATeNT → const int
nbrChapitreNT → const int
nbrChapitreOrdreChronologique → const int
nbrChapitreOrdreHistorique → const int
nirvDbName → const String
nkjvDbName → const String
non → const int
optionsFont → const int
ostrDbName → const String
oui → const int
packageChantChoraleEtGroupe → const String
packageChantChoraleEtGroupeAndroid → const String
packageChantChoraleEtGroupeIos → const String
packageChantdesperanceAndroid → const String
packageChantdesperanceIos → const String
packageChantlyricAndroid → const String
packageChantlyricIos → const String
packageLaSainteBible → const String
packageLyricevangeliqueAndroid → const String
packageLyricevangeliqueIos → const String
packagesNameBrain_dev_bible_app → const String
packagesNameBrain_dev_tools → const String
pdlClick → const String
privacy_policy → const String
quizClick → const String
rv65DbName → const String
saisieAlphaNumeric → const int
saisieAlphaOnly → const int
saisieNumericOnly → const int
slashAppFlutter → const String
stringNew → const int
terms_and_conditions → const String
TOKEN → const String
urlGooglePlayLinkAppRezo509WP → const String
USER_CONNECTED → const String
verseBegin → const int
verseEnd → const int