DeviceAppVersionProperty class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- applicationId → Property
-
final
- appName → Property
-
final
- buildNumber → Property
-
final
- dateCreated → Property
-
final
- isRequired → Property
-
final
- linkAndroid → Property
-
final
- linkApple → Property
-
final
- linkWebSite → Property
-
final
- packageName → Property
-
final
- versionCode → Property
-
final
- versionInfo → Property
-
final
- versionName → Property
-
final