DeviceInfoProperty class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- baseDeviceInfo → Property
-
final
- buildName → Property
-
final
- buildNumber → Property
-
final
- fcmNewToken → Property
-
final
- fcmOldToken → Property
-
final
- identifierForVendor → Property
-
final
- isPhysicalDevice → Property
-
final
- localizedModel → Property
-
final
- model → Property
-
final
- name → Property
-
final
- packageName → Property
-
final
- systemName → Property
-
final
- userName → Property
-
final