ShareModel class

Constructors

ShareModel({Color? colorTop100, Color? colorBottom, bool? isImageOnline, String? pathImage, bool? isHaveImage})
ShareModel.fromMap(Map<String, dynamic> data)
factory

Properties

colorBottom Color?
getter/setter pair
colorTop100 Color?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isHaveImage bool?
getter/setter pair
isImageOnline bool?
getter/setter pair
pathImage String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

captureWidgetImage({required GlobalKey<State<StatefulWidget>> globalKey}) Future<Uint8List?>
copyLyricShareText1({required dynamic chantUser}) String
fromMap(Map<String, dynamic> map) → void
getShareImage({required GlobalKey<State<StatefulWidget>> globalKey, String imageName = 'la_sainte_bible.png'}) Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveImage({required GlobalKey<State<StatefulWidget>> globalKey, required String imageName}) Future<String>
saveImageOnDevice({required Uint8List? uInt8List, required String name}) Future<String>
shareImage({required GlobalKey<State<StatefulWidget>> globalKey, String? msg, String? nameImage}) → dynamic
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

copyLyricShare({required dynamic chantUser}) Future
copyLyricTextData({required dynamic chantUser}) String
launchReviewApp() → dynamic
shareApp() → dynamic
shareLinkAppStoreCCG({bool is4Share = true}) → dynamic
shareLinkAppStoreLSB({bool is4Share = true}) → dynamic
shareTextCEWithLinkCCG({required dynamic ce, required int index}) → dynamic