ShareModel class
Constructors
-
factory
Properties
- colorBottom ↔ Color?
-
getter/setter pair
- colorTop100 ↔ Color?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isHaveImage ↔ bool?
-
getter/setter pair
- isImageOnline ↔ bool?
-
getter/setter pair
- pathImage ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
captureWidgetImage(
{required GlobalKey< State< globalKey}) → Future<StatefulWidget> >Uint8List?> -
fromMap(
Map< String, dynamic> map) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveImage(
{required GlobalKey< State< globalKey, required String imageName}) → Future<StatefulWidget> >String> -
saveImageOnDevice(
{required Uint8List? uInt8List, required String name}) → Future< String> -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
copyLyricTextData(
{required dynamic chantUser}) → String -
launchReviewApp(
) → dynamic