MyLauncherCustomTabs class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
launchAndCloseManually(
) → Future< void> -
launchDeepLinkURL(
) → Future< void> -
launchInExternalBrowser(
) → Future< void> -
launchUrlCustom(
{required String url}) → Future< void> -
launchUrlInBottomSheet(
) → Future< void> -
launchURLInDefaultBrowserOnAndroid(
) → Future< void> -
launchUrlLite(
) → Future< void> -
launchUrlPage(
{required String url}) → Future< void> -
launchWithCustomAnimation(
{required String url, bool showTitle = false}) → Future< void> -
launchWithCustomAnimation2(
{required String url}) → Future< void> -
launchWithCustomCloseButton(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited