ToolsWidget class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
formatTime(
{required Duration duration}) → String -
getColor(
{required bool isDark, Color color = Colors.white}) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
styleReward(
{double fontSize = 12}) → dynamic -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
buildDividerWithContainer(
) → dynamic -
getBadgeMaterial(
String item, {Color materialColors = Colors.deepOrange, Color materialShadowColor = Colors.red, Color textColor = Colors.white, double materialElevation = 5.0, double fontSize = 12.0, FontWeight fontWeight = FontWeight.bold, double width = 25}) → dynamic -
getImageWidget(
{bool? isImageNetworkBg, String? imageBg}) → dynamic