ImageIconResources class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- favorite_sharp ↔ IconData
-
getter/setter pair
-
getter/setter pair
Static Methods
-
checkCircleActiveModeSombreOrNot(
) → IconData -
youtubeIconWidget(
{double horizontal = 5, double vertical = 10}) → dynamic
Constants
- assetsBgHeaderPath → const String
- assetsCoinPath → const String
- assetsCoinStarPath → const String
- assetsFlagAutresPath → const String
- assetsFlagEspagnolPath → const String
- assetsFlagFrancePath → const String
- assetsFlagHaitiPath → const String
- assetsFlagsPath → const String
- assetsFlagUsaPath → const String
- assetsLoginPath → const String
- assetsLogoCcgPath → const String
- assetsLogoCMPath → const String
- assetsLogoRezo509Path → const String
- assetsNoInternetPath → const String
- assetsNoRecordFoundPath → const String
- assetsQuizPath → const String
- bg_ccg_dark → const String
- bg_ccg_light → const String
- bg_chant_desperance_dark → const String
- bg_chant_desperance_light → const String
- bg_chant_lyric_light → const String
- flagCreole → const String
- flagEnglish → const String
- flagEspagnole → const String
- flagFrancais → const String
- flagSaudi → const String
- ic_video → const String
- logoUser → const String
- no_data → const String
- packagesNameBrain_dev_tools → const String
- placeholder → const String