SpeedDialCustom class
Constructors
SpeedDialCustom ({Key ? key , List <SpeedDialChild > children = const [] , bool visible = true , Color ? backgroundColor , Color ? foregroundColor , Color ? activeBackgroundColor , Color ? activeForegroundColor , AnimatedIconData ? animatedIcon , ShapeBorder shape = const StadiumBorder() , Curve curve = Curves.fastOutSlowIn , VoidCallback ? onPress })
const
Properties
activeBackgroundColor
→ Color ?
The color of the background of this SpeedDial when it is open
final
activeForegroundColor
→ Color ?
The color of the foreground of this SpeedDial when it is open
final
animatedIcon
→ AnimatedIconData ?
The animated icon to show as the main button child. If this is provided the child is ignored.
final
backgroundColor
→ Color ?
The tooltip of this SpeedDial
The hero tag used for the fab inside this SpeedDial
The color of the background of this SpeedDial
final
children
→ List <SpeedDialChild >
Children buttons, from the lowest to the highest.
final
curve
→ Curve
The curve used to animate the button on scrolling.
final
foregroundColor
→ Color ?
The color of the foreground of this SpeedDial
final
hashCode
→ int
The hash code for this object.
no setter inherited
key
→ Key ?
Controls how one widget replaces another widget in the tree.
final inherited
onPress
→ VoidCallback ?
The gradient decoration for this SpeedDial
The shape of the gradient decoration for this SpeedDial
Whether speedDial initialize with open state or not, defaults to false.
Whether to close the dial on pop if it's open.
Executed when the dial is opened.
Executed when the dial is closed.
Executed when the dial is pressed. If given, the dial only opens on long press!
final
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
shape
→ ShapeBorder
The intensity of the shadow for this SpeedDial
The size for this SpeedDial button
The size for this SpeedDial children
The shape of this SpeedDial
final
visible
→ bool
Used to get the button hidden on scroll. See examples for more info.
final